==> estateplat-common-1.2.1-20170622.071222-42-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxYhQlr.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/*
 * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
 * @version 1.0, 2017/5/26
 * @description 银行权利人
 */
@Table(name = "gx_yh_qlr")
public class GxYhQlr implements Serializable{
    @Id
    private String qlrid;//权利人主键
    private String ywid;//业务信息id
    private String qlid;//抵押qlid
    private String qlrmc;//权利人名称
    private String qlrsfzjzl;//权利人身份证件种类
    private String qlrzjh;//权利人证件号
    private String qlrtxdz;//权利人通讯地址
    private String qlryb;//权利人邮编
    private String qlrfddbr;//权利人法定代表人
    private String qlrfddbrzjzl;//权利人法定代表人证件种类
    private String qlrfddbrzjh;//权利人法定代表人证件号
    private String qlrfddbrdh;//权利人法定代表人电话
    private String qlrdlr;//权利人代理人
    private String qlrdlrzjzl;//代理人证件种类
    private String qlrdlrzjh;//代理人证件号
    private String qlrdlrdh;//权利人代理人电话
    private String qlrdljg;//权利人代理机构
    private String qlrlx;//权利人类型
    private String qlbl;//权利比例
    private String gyfs;//共有方式
    private String qlrxz;//权利人性质
    private String qlrlxdh;//权利人联系电话
    private String sshy;//所属行业
    private String bz;//备注
    private String sfczr;//是否持证人
    private int sxh;//顺序号
    private String gyqk;//共有情况
    private String xb;//性别
    private  String qygyr;//其余共有人

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getQlrsfzjzl() {
        return qlrsfzjzl;
    }

    public void setQlrsfzjzl(String qlrsfzjzl) {
        this.qlrsfzjzl = qlrsfzjzl;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getQlrtxdz() {
        return qlrtxdz;
    }

    public void setQlrtxdz(String qlrtxdz) {
        this.qlrtxdz = qlrtxdz;
    }

    public String getQlryb() {
        return qlryb;
    }

    public void setQlryb(String qlryb) {
        this.qlryb = qlryb;
    }

    public String getQlrfddbr() {
        return qlrfddbr;
    }

    public void setQlrfddbr(String qlrfddbr) {
        this.qlrfddbr = qlrfddbr;
    }

    public String getQlrfddbrzjzl() {
        return qlrfddbrzjzl;
    }

    public void setQlrfddbrzjzl(String qlrfddbrzjzl) {
        this.qlrfddbrzjzl = qlrfddbrzjzl;
    }

    public String getQlrfddbrzjh() {
        return qlrfddbrzjh;
    }

    public void setQlrfddbrzjh(String qlrfddbrzjh) {
        this.qlrfddbrzjh = qlrfddbrzjh;
    }

    public String getQlrfddbrdh() {
        return qlrfddbrdh;
    }

    public void setQlrfddbrdh(String qlrfddbrdh) {
        this.qlrfddbrdh = qlrfddbrdh;
    }

    public String getQlrdlr() {
        return qlrdlr;
    }

    public void setQlrdlr(String qlrdlr) {
        this.qlrdlr = qlrdlr;
    }

    public String getQlrdlrzjzl() {
        return qlrdlrzjzl;
    }

    public void setQlrdlrzjzl(String qlrdlrzjzl) {
        this.qlrdlrzjzl = qlrdlrzjzl;
    }

    public String getQlrdlrzjh() {
        return qlrdlrzjh;
    }

    public void setQlrdlrzjh(String qlrdlrzjh) {
        this.qlrdlrzjh = qlrdlrzjh;
    }

    public String getQlrdlrdh() {
        return qlrdlrdh;
    }

    public void setQlrdlrdh(String qlrdlrdh) {
        this.qlrdlrdh = qlrdlrdh;
    }

    public String getQlrdljg() {
        return qlrdljg;
    }

    public void setQlrdljg(String qlrdljg) {
        this.qlrdljg = qlrdljg;
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx;
    }

    public String getQlbl() {
        return qlbl;
    }

    public void setQlbl(String qlbl) {
        this.qlbl = qlbl;
    }

    public String getGyfs() {
        return gyfs;
    }

    public void setGyfs(String gyfs) {
        this.gyfs = gyfs;
    }

    public String getQlrxz() {
        return qlrxz;
    }

    public void setQlrxz(String qlrxz) {
        this.qlrxz = qlrxz;
    }

    public String getQlrlxdh() {
        return qlrlxdh;
    }

    public void setQlrlxdh(String qlrlxdh) {
        this.qlrlxdh = qlrlxdh;
    }

    public String getSshy() {
        return sshy;
    }

    public void setSshy(String sshy) {
        this.sshy = sshy;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSfczr() {
        return sfczr;
    }

    public void setSfczr(String sfczr) {
        this.sfczr = sfczr;
    }

    public int getSxh() {
        return sxh;
    }

    public void setSxh(int sxh) {
        this.sxh = sxh;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public String getQygyr() {
        return qygyr;
    }

    public void setQygyr(String qygyr) {
        this.qygyr = qygyr;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }
}

==> estateplat-common-1.2.3-20180615.013919-122-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxYhQlr.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/*
 * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
 * @version 1.0, 2017/5/26
 * @description 银行权利人
 */
@Table(name = "gx_yh_qlr")
public class GxYhQlr implements Serializable{
    @Id
    private String qlrid;//权利人主键
    private String ywid;//业务信息id
    private String qlid;//抵押qlid
    private String qlrmc;//权利人名称
    private String qlrsfzjzl;//权利人身份证件种类
    private String qlrzjh;//权利人证件号
    private String qlrtxdz;//权利人通讯地址
    private String qlryb;//权利人邮编
    private String qlrfddbr;//权利人法定代表人
    private String qlrfddbrzjzl;//权利人法定代表人证件种类
    private String qlrfddbrzjh;//权利人法定代表人证件号
    private String qlrfddbrdh;//权利人法定代表人电话
    private String qlrdlr;//权利人代理人
    private String qlrdlrzjzl;//代理人证件种类
    private String qlrdlrzjh;//代理人证件号
    private String qlrdlrdh;//权利人代理人电话
    private String qlrdljg;//权利人代理机构
    private String qlrlx;//权利人类型
    private String qlbl;//权利比例
    private String gyfs;//共有方式
    private String qlrxz;//权利人性质
    private String qlrlxdh;//权利人联系电话
    private String sshy;//所属行业
    private String bz;//备注
    private String sfczr;//是否持证人
    private Integer sxh;//顺序号
    private String gyqk;//共有情况
    private String xb;//性别
    private  String qygyr;//其余共有人

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getQlrsfzjzl() {
        return qlrsfzjzl;
    }

    public void setQlrsfzjzl(String qlrsfzjzl) {
        this.qlrsfzjzl = qlrsfzjzl;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getQlrtxdz() {
        return qlrtxdz;
    }

    public void setQlrtxdz(String qlrtxdz) {
        this.qlrtxdz = qlrtxdz;
    }

    public String getQlryb() {
        return qlryb;
    }

    public void setQlryb(String qlryb) {
        this.qlryb = qlryb;
    }

    public String getQlrfddbr() {
        return qlrfddbr;
    }

    public void setQlrfddbr(String qlrfddbr) {
        this.qlrfddbr = qlrfddbr;
    }

    public String getQlrfddbrzjzl() {
        return qlrfddbrzjzl;
    }

    public void setQlrfddbrzjzl(String qlrfddbrzjzl) {
        this.qlrfddbrzjzl = qlrfddbrzjzl;
    }

    public String getQlrfddbrzjh() {
        return qlrfddbrzjh;
    }

    public void setQlrfddbrzjh(String qlrfddbrzjh) {
        this.qlrfddbrzjh = qlrfddbrzjh;
    }

    public String getQlrfddbrdh() {
        return qlrfddbrdh;
    }

    public void setQlrfddbrdh(String qlrfddbrdh) {
        this.qlrfddbrdh = qlrfddbrdh;
    }

    public String getQlrdlr() {
        return qlrdlr;
    }

    public void setQlrdlr(String qlrdlr) {
        this.qlrdlr = qlrdlr;
    }

    public String getQlrdlrzjzl() {
        return qlrdlrzjzl;
    }

    public void setQlrdlrzjzl(String qlrdlrzjzl) {
        this.qlrdlrzjzl = qlrdlrzjzl;
    }

    public String getQlrdlrzjh() {
        return qlrdlrzjh;
    }

    public void setQlrdlrzjh(String qlrdlrzjh) {
        this.qlrdlrzjh = qlrdlrzjh;
    }

    public String getQlrdlrdh() {
        return qlrdlrdh;
    }

    public void setQlrdlrdh(String qlrdlrdh) {
        this.qlrdlrdh = qlrdlrdh;
    }

    public String getQlrdljg() {
        return qlrdljg;
    }

    public void setQlrdljg(String qlrdljg) {
        this.qlrdljg = qlrdljg;
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx;
    }

    public String getQlbl() {
        return qlbl;
    }

    public void setQlbl(String qlbl) {
        this.qlbl = qlbl;
    }

    public String getGyfs() {
        return gyfs;
    }

    public void setGyfs(String gyfs) {
        this.gyfs = gyfs;
    }

    public String getQlrxz() {
        return qlrxz;
    }

    public void setQlrxz(String qlrxz) {
        this.qlrxz = qlrxz;
    }

    public String getQlrlxdh() {
        return qlrlxdh;
    }

    public void setQlrlxdh(String qlrlxdh) {
        this.qlrlxdh = qlrlxdh;
    }

    public String getSshy() {
        return sshy;
    }

    public void setSshy(String sshy) {
        this.sshy = sshy;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSfczr() {
        return sfczr;
    }

    public void setSfczr(String sfczr) {
        this.sfczr = sfczr;
    }

    public Integer getSxh() {
        return sxh;
    }

    public void setSxh(Integer sxh) {
        this.sxh = sxh;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public String getQygyr() {
        return qygyr;
    }

    public void setQygyr(String qygyr) {
        this.qygyr = qygyr;
    }
}
